@@ -3,35 +3,8 @@
 # Univention Management Console
 #  module: manages system services
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2011-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2011-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from typing import Any
 
@@ -100,7 +73,7 @@ class Instance(Base):
             try:
                 getattr(service, action)()
             except ServiceError as exc:
-                MODULE.warn(f'Error during {action} of {srv}: {exc}')
+                MODULE.warning("Error during %s of %s: %s", action, srv, exc)
                 error_messages.append('%s\n%s' % ({
                     'start': _('Starting the service %s failed:'),
                     'stop': _('Stopping the service %s failed:'),
